@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "L'adreça de correu no és vàlida",
     "%s has published the calendar »%s«" : "%s ha publicat el calendari «%s»",
     "Unexpected error sending email. Please contact your administrator." : "Error inesperat en enviar el correu. Contacteu amb l'administrador.",
-    "Successfully sent email to " : "S'ha enviat el correu amb èxit a ",
     "Hello," : "Hola,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Us volem informar que %s ha publicat el calendari «%s».",
     "Open »%s«" : "Obre »%s«",
@@ -78,6 +77,7 @@ OC.L10N.register(
     "Creating subscription …" : "S'està creant la subscripció …",
     "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
+    "Untitled event" : "Esdeveniment sense títol",
     "Could not update calendar order." : "No s'ha pogut actualitzar l'ordre del calendari.",
     "Import calendars" : "Importar calendaris",
     "Please select a calendar to import into …" : "Escolliu un calendari per ser importat …",
@@ -137,36 +137,26 @@ OC.L10N.register(
     "_week_::_weeks_" : ["setmana","setmanes"],
     "No reminders yet" : "Encara no hi ha recordatoris",
     "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
+    "Free" : "Lliure",
     "Busy (tentative)" : "Ocupat (temptativament)",
     "Busy" : "Ocupat",
     "Out of office" : "Fora de la oficina",
     "Unknown" : "Desconegut",
-    "{name} accepted your invitation." : "{name} ha acceptat la vostra invitació.",
-    "{name} accepted {organizerName}'s invitation." : "{name} ha acceptat la invitació de {organizerName}.",
-    "{name} declined your invitation." : "{name} ha rebutjat la vostra invitació.",
-    "{name} declined {organizerName}'s invitation." : "{name} ha rebutjat la invitació de {organizerName}.",
-    "{name} has delegated their invitation." : "{name} ha delegat la seva invitació.",
-    "{name} marked their participation as tentative." : "{name} han marcat la seva participació com a temptativa.",
-    "{name} did not respond to your invitation yet." : "{name} encara no ha respost a la vostra invitació.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} encara no ha respost a la invitació de {organizerName}.",
     "Create Talk room for this event" : "Crear una sala a Talk per a aquest event",
     "Show busy times" : "Mostra els horaris ocupats",
     "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala del Talk a la descripció de l'event.",
     "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
-    "Send e-mail" : "Envia el correu",
     "Chairperson" : "S'està convocant",
     "Required participant" : "Participant necessari",
     "Optional participant" : "Participant opcional",
     "Non-participant" : "No-participant",
     "Remove attendee" : "Treu el participant",
-    "Search for e-mails, users, contacts, resources or rooms" : "Cerca correus, usuaris, contactes, recursos o espais",
     "No match found" : "No s'ha trobat res",
     "No attendees yet" : "Encara sense participants",
     "(organizer)" : "(organitzador)",
     "Remove color" : "Treu el color",
     "Event title" : "Títol de l'event",
     "All day" : "Tot el dia",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "No es pot modificar la opció de dia-sencer pels events que formen part d'un conjunt recurrent.",
     "from {startDate}" : "del {startDate}",
     "from {startDate} at {startTime}" : "de {startDate} a {startTime}",
     "to {endDate}" : "fins al {endDate}",
@@ -177,7 +167,6 @@ OC.L10N.register(
     "on date" : "a temps",
     "after" : "després de",
     "_time_::_times_" : ["hora","hores"],
-    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Aquest event és una excepció de recurrència d'un conjunt de recurrència. No se li pot afegir una regla recurrència.",
     "first" : "primer",
     "third" : "tercer",
     "fourth" : "quart",
@@ -279,17 +268,9 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "al {monthNames} al {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "fins el {untilDate}",
     "_%n time_::_%n times_" : ["%n vegada","%n vegades"],
-    "Untitled event" : "Esdeveniment sense títol",
     "Untitled task" : "Tasca sense títol",
     "Please ask your administrator to enable the Tasks App." : "Demaneu al vostre administrador que habiliti l'aplicació de Tasques.",
-    "prev" : "anterior",
-    "next" : "següent",
-    "prev year" : "any anterior",
-    "next year" : "any següent",
-    "today" : "avui",
-    "list" : "llista",
     "W" : "S",
-    "all-day" : "tot el dia",
     "%n more" : "%n més",
     "No events to display" : "No hi ha esdeveniments per visualitzar",
     "_+%n more_::_+%n more_" : ["+%n més","+%n més"],
@@ -313,7 +294,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Confirmació sobre l'estat general de l'event.",
     "Show as" : "Mostra com",
     "Take this event into account when calculating free-busy information." : "Tenir en compte aquest event quan es calculi informació sobre disponibilitat-ocupació.",
-    "Free" : "Lliure",
     "Categories" : "Categories",
     "Categories help you to structure and organize your events." : "Les categories us ajuden a estructurar i organitzar els vostres events.",
     "Search or add categories" : "Cercar o afegir categories",
@@ -341,14 +321,10 @@ OC.L10N.register(
     "Review" : "Revisa",
     "Office" : "Oficina",
     "Contributor week" : "Setmana del contribuïdor",
-    "Party" : "Festa",
-    "Celebration" : "Celebració",
     "Mail" : "Correu electrònic",
     "Soccer" : "Futbol",
     "Football" : "Futbol americà",
     "Gaming" : "Jugar",
-    "Play" : "Reprodueix",
-    "Game" : "Joc",
     "Drive" : "Conduir",
     "Bicycle" : "Bicicleta",
     "Cycle" : "Ciclisme",
@@ -402,6 +378,8 @@ OC.L10N.register(
     "Lecture" : "Lectura",
     "Seminar" : "Seminari",
     "Photograph" : "Fotografia",
+    "Party" : "Festa",
+    "Celebration" : "Celebració",
     "Celebrate" : "Celebrar",
     "Shopping" : "Anar de compres",
     "Skate" : "Patinar",
