@@ -39,7 +39,6 @@ OC.L10N.register(
     "Close" : "Cau",
     "Anniversary" : "Dathliad",
     "Week {number} of {year}" : "Wythnos {number} o {year}",
-    "today" : "heddiw",
     "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
     "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
     "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
@@ -48,7 +47,6 @@ OC.L10N.register(
     "Confirmed" : "Cadarnhawyd",
     "Tentative" : "I'w gadarnhau",
     "Mail" : "E-bost",
-    "Play" : "Chwarae",
     "Global" : "Eang"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
