@@ -69,8 +69,6 @@ OC.L10N.register(
     "Weekly" : "Iga nädal",
     "Monthly" : "Igakuine",
     "Yearly" : "Igaastane",
-    "next year" : "järgmine aasta",
-    "today" : "täna",
     "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
     "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
@@ -89,13 +87,9 @@ OC.L10N.register(
     "Brainstorm" : "Ajutorm",
     "Baseball" : "Pesapall",
     "Office" : "Kontor",
-    "Party" : "Pidu",
-    "Celebration" : "Tähistamine",
     "Mail" : "Kirjad",
     "Soccer" : "Jalgpall",
     "Football" : "Ameerika jalgpall",
-    "Play" : "Esita",
-    "Game" : "Mäng",
     "Drive" : "Sõit",
     "Bicycle" : "Jalgratas",
     "Biking" : "Jalgrattaga sõitmine",
@@ -135,6 +129,8 @@ OC.L10N.register(
     "Lecture" : "Loeng",
     "Seminar" : "Seminar",
     "Photograph" : "Foto",
+    "Party" : "Pidu",
+    "Celebration" : "Tähistamine",
     "Celebrate" : "Tähista",
     "Skate" : "Uisutamine",
     "Skateboard" : "Rula",
