@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Provided email-address is not valid" : "Oppgitt e-postadresse er ikke gyldig",
     "%s has published the calendar »%s«" : "%s har publisert kalenderen \"%s\"",
-    "Successfully sent email to " : "E-post er sendt til",
     "Hello," : "Hei,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønsker å informere deg om at %s har publisert kalenderen \"%s\".",
     "Open »%s«" : "Åpne \"%s\"",
@@ -76,6 +75,7 @@ OC.L10N.register(
     "Creating subscription …" : "Oppretter abonnement ...",
     "An error occurred, unable to create the calendar." : "En feil oppstod, kunne ikke opprette kalenderen",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vennligst angi gyldig lenke (starte med http://, https://, webcal://, eller webcals://)",
+    "Untitled event" : "Hendelse uten tittel",
     "Could not update calendar order." : "Kunne ikke oppdatere rekkefølgen på kalendrene.",
     "Import calendars" : "Importer kalendere",
     "Please select a calendar to import into …" : "Vennligst velg en kalender å importere til ...",
@@ -135,29 +135,20 @@ OC.L10N.register(
     "_week_::_weeks_" : ["uke","uker"],
     "No reminders yet" : "Ingen påminnelser enda",
     "Availability of attendees, resources and rooms" : "Tilgjengelighet til deltagere, ressurser og rom",
+    "Free" : "Ledig",
     "Busy (tentative)" : "Opptatt (foreløpig)",
     "Busy" : "Opptatt",
     "Out of office" : "Fraværende",
     "Unknown" : "Ukjent",
-    "{name} accepted your invitation." : "{name} aksepterte din invitasjon.",
-    "{name} accepted {organizerName}'s invitation." : "{name} aksepterte {organizerName}s invitasjon.",
-    "{name} declined your invitation." : "{name} avslo din invitasjon.",
-    "{name} declined {organizerName}'s invitation." : "{name} avslo {organizerName}s invitasjon.",
-    "{name} has delegated their invitation." : "{name} har delegert deres invitasjon.",
-    "{name} marked their participation as tentative." : "{name} markerte sin deltakelse som mulig.",
-    "{name} did not respond to your invitation yet." : "{name} har ikke respondert på din invitasjon enda.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} har ikke svart på {organizerName}s invitasjon enda.",
     "Create Talk room for this event" : "Opprett Talk-rom for denne hendelsen",
     "Show busy times" : "Vis opptatte tider",
     "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
     "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
-    "Send e-mail" : "Send e-post",
     "Chairperson" : "Ordstyrer",
     "Required participant" : "Påkrevd deltaker",
     "Optional participant" : "Ønsket deltaker",
     "Non-participant" : "Ikke-deltaker",
     "Remove attendee" : "Fjern deltaker",
-    "Search for e-mails, users, contacts, resources or rooms" : "Søk for e-poster, brukere, kontakter, ressurser eller rom",
     "No match found" : "Ingen treff",
     "No attendees yet" : "Ingen deltagere enda",
     "(organizer)" : "(organisator)",
@@ -239,11 +230,7 @@ OC.L10N.register(
     "Weekly" : "Ukentlig",
     "Monthly" : "Månedlig",
     "Yearly" : "Årlig",
-    "Untitled event" : "Hendelse uten tittel",
     "Untitled task" : "Oppgave uten tittel",
-    "next year" : "neste år",
-    "today" : "i dag",
-    "all-day" : "Heldags",
     "No events" : "Ingen hendelser",
     "When shared show" : "Når delt vis",
     "When shared show full event" : "Vis hele hendelsen når delt",
@@ -259,7 +246,6 @@ OC.L10N.register(
     "Tentative" : "Foreløpig",
     "Canceled" : "Avbrutt",
     "Show as" : "Vis som",
-    "Free" : "Ledig",
     "Categories" : "Kategorier",
     "Search or add categories" : "Søk eller legg til kategorier",
     "Add this as a new category" : "Legg til som ny kategori",
@@ -278,12 +264,9 @@ OC.L10N.register(
     "Planning" : "Planlegge",
     "Review" : "Anmeldelse",
     "Office" : "Office",
-    "Party" : "Fest",
-    "Celebration" : "Feiring",
     "Mail" : "E-post",
     "Soccer" : "Fotball",
     "Gaming" : "Gaming",
-    "Play" : "Spill",
     "Drive" : "Kjøre",
     "Bicycle" : "Sykkel",
     "Cycle" : "Sykle",
@@ -331,6 +314,8 @@ OC.L10N.register(
     "Lecture" : "Forelesning",
     "Seminar" : "Seminar",
     "Photograph" : "Fotografere",
+    "Party" : "Fest",
+    "Celebration" : "Feiring",
     "Celebrate" : "Feire",
     "Shopping" : "Shoppe",
     "Skate" : "Skate",
