@@ -21,9 +21,7 @@ OC.L10N.register(
     "Personal" : "شەخسىي",
     "Attendees" : "قاتناشقۇچىلار",
     "Close" : "ياپ",
-    "today" : "بۈگۈن",
     "Location" : "ئورنى",
-    "Description" : "چۈشەندۈرۈش",
-    "Play" : "چال"
+    "Description" : "چۈشەندۈرۈش"
 },
 "nplurals=2; plural=(n != 1);");
